@@ -1,4 +1,6 @@
 """
 Init for file for actions package.
 """
-from .actions import Actions  # noqa: F401
+# flake8: noqa
+
+from .actions import Actions
