@@ -1,65 +1,61 @@
 """
 Interact with reactions to various GitHub entities.
 """
+# pylint: disable=too-many-arguments, too-many-public-methods, too-many-lines, duplicate-code, line-too-long
 
 
-# pylint: disable=too-many-arguments
 class Reactions:
-    # pylint: disable=too-many-public-methods
     """
     Interact with reactions to various GitHub entities.
     """
 
     def __init__(self, client):
         """
-        Initialize the Reactions class.
+        Initializes the Reactions class.
         """
         self._base_url = client._base_url
         self._execute = client._execute
 
     def list_reactions_for_a_team_discussion_comment(
-        self, org, team_slug, discussion_number, comment_number, params=None, payload=None
+        self,
+        org,
+        team_slug,
+        discussion_number,
+        comment_number,
+        params=None,
+        payload=None,
     ):
         """
+        Summary:
         List reactions for a team discussion comment
+        Docs:
         https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion-comment
-        Attributes:
-        Path Parameters:
-        org
-        team_slug
-        discussion_number
-        comment_number
-        Payload Parameters:
-        content
-         per-page
-         page
         """
         url = (
             self._base_url
-            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
+            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions"
         )
         response = self._execute("get", url, params=params, payload=payload)
         return response
 
     def create_reaction_for_a_team_discussion_comment(
-        self, org, team_slug, discussion_number, comment_number, params=None, payload=None
+        self,
+        org,
+        team_slug,
+        discussion_number,
+        comment_number,
+        params=None,
+        payload=None,
     ):
-
         """
+        Summary:
         Create reaction for a team discussion comment
+        Docs:
         https://docs.github.com/rest/reference/reactions#create-reaction-for-a-team-discussion-comment
-        Attributes:
-        Path Parameters:
-        org
-        team_slug
-        discussion_number
-        comment_number
-        Payload Parameters:
-
         """
         url = (
             self._base_url
-            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
+            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions"
         )
         response = self._execute("post", url, params=params, payload=payload)
         return response
@@ -74,23 +70,15 @@ class Reactions:
         params=None,
         payload=None,
     ):
-
         """
+        Summary:
         Delete team discussion comment reaction
+        Docs:
         https://docs.github.com/rest/reference/reactions#delete-team-discussion-comment-reaction
-        Attributes:
-        Path Parameters:
-        org
-        team_slug
-        discussion_number
-        comment_number
-        reaction_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
-            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions/{reaction_id}"  # pylint: disable=line-too-long # noqa: E501
+            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions/{reaction_id}"
         )
         response = self._execute("delete", url, params=params, payload=payload)
         return response
@@ -99,17 +87,10 @@ class Reactions:
         self, org, team_slug, discussion_number, params=None, payload=None
     ):
         """
+        Summary:
         List reactions for a team discussion
+        Docs:
         https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion
-        Attributes:
-        Path Parameters:
-        org
-        team_slug
-        discussion_number
-        Payload Parameters:
-        content
-         per-page
-         page
         """
         url = (
             self._base_url
@@ -122,15 +103,10 @@ class Reactions:
         self, org, team_slug, discussion_number, params=None, payload=None
     ):
         """
+        Summary:
         Create reaction for a team discussion
+        Docs:
         https://docs.github.com/rest/reference/reactions#create-reaction-for-a-team-discussion
-        Attributes:
-        Path Parameters:
-        org
-        team_slug
-        discussion_number
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -143,20 +119,14 @@ class Reactions:
         self, org, team_slug, discussion_number, reaction_id, params=None, payload=None
     ):
         """
+        Summary:
         Delete team discussion reaction
+        Docs:
         https://docs.github.com/rest/reference/reactions#delete-team-discussion-reaction
-        Attributes:
-        Path Parameters:
-        org
-        team_slug
-        discussion_number
-        reaction_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
-            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/reactions/{reaction_id}"  # pylint: disable=line-too-long # noqa: E501
+            + f"/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/reactions/{reaction_id}"
         )
         response = self._execute("delete", url, params=params, payload=payload)
         return response
@@ -165,17 +135,10 @@ class Reactions:
         self, owner, repo, comment_id, params=None, payload=None
     ):
         """
+        Summary:
         List reactions for a commit comment
+        Docs:
         https://docs.github.com/rest/reference/reactions#list-reactions-for-a-commit-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-        content
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}/reactions"
         response = self._execute("get", url, params=params, payload=payload)
@@ -185,15 +148,10 @@ class Reactions:
         self, owner, repo, comment_id, params=None, payload=None
     ):
         """
+        Summary:
         Create reaction for a commit comment
+        Docs:
         https://docs.github.com/rest/reference/reactions#create-reaction-for-a-commit-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}/reactions"
         response = self._execute("post", url, params=params, payload=payload)
@@ -203,16 +161,10 @@ class Reactions:
         self, owner, repo, comment_id, reaction_id, params=None, payload=None
     ):
         """
+        Summary:
         Delete a commit comment reaction
+        Docs:
         https://docs.github.com/rest/reference/reactions#delete-a-commit-comment-reaction
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        reaction_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url + f"/repos/{owner}/{repo}/comments/{comment_id}/reactions/{reaction_id}"
@@ -224,17 +176,10 @@ class Reactions:
         self, owner, repo, comment_id, params=None, payload=None
     ):
         """
+        Summary:
         List reactions for an issue comment
+        Docs:
         https://docs.github.com/rest/reference/reactions#list-reactions-for-an-issue-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-        content
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}/reactions"
         response = self._execute("get", url, params=params, payload=payload)
@@ -244,15 +189,10 @@ class Reactions:
         self, owner, repo, comment_id, params=None, payload=None
     ):
         """
+        Summary:
         Create reaction for an issue comment
+        Docs:
         https://docs.github.com/rest/reference/reactions#create-reaction-for-an-issue-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/comments/{comment_id}/reactions"
         response = self._execute("post", url, params=params, payload=payload)
@@ -262,16 +202,10 @@ class Reactions:
         self, owner, repo, comment_id, reaction_id, params=None, payload=None
     ):
         """
+        Summary:
         Delete an issue comment reaction
+        Docs:
         https://docs.github.com/rest/reference/reactions#delete-an-issue-comment-reaction
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        reaction_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -282,17 +216,10 @@ class Reactions:
 
     def list_reactions_for_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         List reactions for an issue
+        Docs:
         https://docs.github.com/rest/reference/reactions#list-reactions-for-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-        content
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/reactions"
         response = self._execute("get", url, params=params, payload=payload)
@@ -300,15 +227,10 @@ class Reactions:
 
     def create_reaction_for_an_issue(self, owner, repo, issue_number, params=None, payload=None):
         """
+        Summary:
         Create reaction for an issue
+        Docs:
         https://docs.github.com/rest/reference/reactions#create-reaction-for-an-issue
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/reactions"
         response = self._execute("post", url, params=params, payload=payload)
@@ -318,16 +240,10 @@ class Reactions:
         self, owner, repo, issue_number, reaction_id, params=None, payload=None
     ):
         """
+        Summary:
         Delete an issue reaction
+        Docs:
         https://docs.github.com/rest/reference/reactions#delete-an-issue-reaction
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        issue_number
-        reaction_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url + f"/repos/{owner}/{repo}/issues/{issue_number}/reactions/{reaction_id}"
@@ -339,17 +255,10 @@ class Reactions:
         self, owner, repo, comment_id, params=None, payload=None
     ):
         """
+        Summary:
         List reactions for a pull request review comment
+        Docs:
         https://docs.github.com/rest/reference/reactions#list-reactions-for-a-pull-request-review-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-        content
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}/reactions"
         response = self._execute("get", url, params=params, payload=payload)
@@ -359,15 +268,10 @@ class Reactions:
         self, owner, repo, comment_id, params=None, payload=None
     ):
         """
+        Summary:
         Create reaction for a pull request review comment
+        Docs:
         https://docs.github.com/rest/reference/reactions#create-reaction-for-a-pull-request-review-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/pulls/comments/{comment_id}/reactions"
         response = self._execute("post", url, params=params, payload=payload)
@@ -376,18 +280,11 @@ class Reactions:
     def delete_a_pull_request_comment_reaction(
         self, owner, repo, comment_id, reaction_id, params=None, payload=None
     ):
-
         """
+        Summary:
         Delete a pull request comment reaction
+        Docs:
         https://docs.github.com/rest/reference/reactions#delete-a-pull-request-comment-reaction
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        comment_id
-        reaction_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url
@@ -396,102 +293,12 @@ class Reactions:
         response = self._execute("delete", url, params=params, payload=payload)
         return response
 
-    def list_reactions_for_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, comment_id, params=None, payload=None
-    ):
-
-        """
-        List reactions for a pull request thread comment
-        https://docs.github.com/rest/reference/reactions#list-reactions-for-a-pull-request-thread-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        thread_id
-        comment_id
-        Payload Parameters:
-        content
-         per-page
-         page
-        """
-        url = (
-            self._base_url
-            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}/reactions"  # pylint: disable=line-too-long # noqa: E501
-        )
-        response = self._execute("get", url, params=params, payload=payload)
-        return response
-
-    def create_a_reaction_to_a_pull_request_thread_comment(
-        self, owner, repo, pull_number, thread_id, comment_id, params=None, payload=None
-    ):
-
-        """
-        Create a reaction to a pull request thread comment
-        https://docs.github.com/rest/reference/reactions#create-a-reaction-to-a-pull-request-thread-comment
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        thread_id
-        comment_id
-        Payload Parameters:
-
-        """
-        url = (
-            self._base_url
-            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}/reactions"  # pylint: disable=line-too-long # noqa: E501
-        )
-        response = self._execute("post", url, params=params, payload=payload)
-        return response
-
-    def delete_a_reaction_to_a_pull_request_thread_comment(
-        self,
-        owner,
-        repo,
-        pull_number,
-        thread_id,
-        comment_id,
-        reaction_id,
-        params=None,
-        payload=None,
-    ):
-
-        """
-        Delete a reaction to a pull request thread comment
-        https://docs.github.com/rest/reference/reactions#delete-a-thread-comment-reaction
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        pull_number
-        thread_id
-        comment_id
-        reaction_id
-        Payload Parameters:
-
-        """
-        url = (
-            self._base_url
-            + f"/repos/{owner}/{repo}/pulls/{pull_number}/threads/{thread_id}/comments/{comment_id}/reactions/{reaction_id}"  # pylint: disable=line-too-long # noqa: E501
-        )
-        response = self._execute("delete", url, params=params, payload=payload)
-        return response
-
     def list_reactions_for_a_release(self, owner, repo, release_id, params=None, payload=None):
         """
+        Summary:
         List reactions for a release
+        Docs:
         https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-release
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        release_id
-        Payload Parameters:
-        content
-         per-page
-         page
         """
         url = self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}/reactions"
         response = self._execute("get", url, params=params, payload=payload)
@@ -499,15 +306,10 @@ class Reactions:
 
     def create_reaction_for_a_release(self, owner, repo, release_id, params=None, payload=None):
         """
+        Summary:
         Create reaction for a release
+        Docs:
         https://docs.github.com/rest/reference/reactions/#create-reaction-for-a-release
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        release_id
-        Payload Parameters:
-
         """
         url = self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}/reactions"
         response = self._execute("post", url, params=params, payload=payload)
@@ -517,16 +319,10 @@ class Reactions:
         self, owner, repo, release_id, reaction_id, params=None, payload=None
     ):
         """
+        Summary:
         Delete a release reaction
+        Docs:
         https://docs.github.com/rest/reference/reactions/#delete-a-release-reaction
-        Attributes:
-        Path Parameters:
-        owner
-        repo
-        release_id
-        reaction_id
-        Payload Parameters:
-
         """
         url = (
             self._base_url + f"/repos/{owner}/{repo}/releases/{release_id}/reactions/{reaction_id}"
@@ -538,21 +334,14 @@ class Reactions:
         self, team_id, discussion_number, comment_number, params=None, payload=None
     ):
         """
+        Summary:
         List reactions for a team discussion comment (Legacy)
+        Docs:
         https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-team-discussion-comment-legacy
-        Attributes:
-        Path Parameters:
-        team_id
-        discussion_number
-        comment_number
-        Payload Parameters:
-        content
-         per-page
-         page
         """
         url = (
             self._base_url
-            + f"/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
+            + f"/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}/reactions"
         )
         response = self._execute("get", url, params=params, payload=payload)
         return response
@@ -561,19 +350,14 @@ class Reactions:
         self, team_id, discussion_number, comment_number, params=None, payload=None
     ):
         """
+        Summary:
         Create reaction for a team discussion comment (Legacy)
+        Docs:
         https://docs.github.com/rest/reference/reactions/#create-reaction-for-a-team-discussion-comment-legacy
-        Attributes:
-        Path Parameters:
-        team_id
-        discussion_number
-        comment_number
-        Payload Parameters:
-
         """
         url = (
             self._base_url
-            + f"/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}/reactions"  # pylint: disable=line-too-long # noqa: E501
+            + f"/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}/reactions"
         )
         response = self._execute("post", url, params=params, payload=payload)
         return response
@@ -582,16 +366,10 @@ class Reactions:
         self, team_id, discussion_number, params=None, payload=None
     ):
         """
+        Summary:
         List reactions for a team discussion (Legacy)
+        Docs:
         https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-team-discussion-legacy
-        Attributes:
-        Path Parameters:
-        team_id
-        discussion_number
-        Payload Parameters:
-        content
-         per-page
-         page
         """
         url = self._base_url + f"/teams/{team_id}/discussions/{discussion_number}/reactions"
         response = self._execute("get", url, params=params, payload=payload)
@@ -601,14 +379,10 @@ class Reactions:
         self, team_id, discussion_number, params=None, payload=None
     ):
         """
+        Summary:
         Create reaction for a team discussion (Legacy)
+        Docs:
         https://docs.github.com/rest/reference/reactions/#create-reaction-for-a-team-discussion-legacy
-        Attributes:
-        Path Parameters:
-        team_id
-        discussion_number
-        Payload Parameters:
-
         """
         url = self._base_url + f"/teams/{team_id}/discussions/{discussion_number}/reactions"
         response = self._execute("post", url, params=params, payload=payload)
