@@ -25,12 +25,13 @@ class RestClient:
     The following methods are used to form requests to the GitHub REST API.
     """
 
-    def __init__(self, hostname=None, api_token=None):
+    def __init__(self, hostname=None, api_token=None, verify=None):
         """
         Initialize the REST client to make requests to the GitHub API.
         Attributes:
             api_token (str): GitHub API token.
             hostname (str): GitHub URL Slug (only needed if using GHES).
+            verify (bool): Verify SSL certificate.
         """
         if api_token is None:
             api_token = os.environ.get("API_TOKEN")
@@ -47,6 +48,7 @@ class RestClient:
             rest_api_url = "https://" + hostname + "/api/v3"
 
         self._base_url = rest_api_url
+        self._verify = verify
         self.actions = apis.actions.Actions(self)
         self.activity = apis.activity.Activity(self)
         self.apps = apis.apps.Apps(self)
@@ -97,7 +99,7 @@ class RestClient:
             url = response.links.get("next").get("url")
             response = self._execute("GET", url)
 
-    def _execute(self, method, url, payload=None, params=None, verify=True):
+    def _execute(self, method, url, payload=None, params=None):
         """
         Execute a request.
 
@@ -114,7 +116,7 @@ class RestClient:
                 json=payload,
                 headers=self._headers,
                 timeout=10,
-                verify=verify,
+                verify=self._verify,
             )
             response.raise_for_status()
             return response
